## v3.0.1 (2025-07-20)

### Fix

- failing test update uv workflow version
- failing tests
- :rotating_light: removed outdated type declaration
- **deps**: update dependency aiomqtt to ~=2.4.0

## v3.0.0 (2024-12-25)

### BREAKING CHANGE

- Removing AsyncTyper
fixes #12

### Refactor

- :fire: Removing async typer custom implementation using alternative implementation in skills
- :recycle: Updating copier template, migrating to uv

## v2.1.0 (2024-11-30)

### Feat

- :sparkles: Allowing skill prepartions to be executed

## v2.0.0 (2024-11-24)

### BREAKING CHANGE

- Renamed publish methods and made response an object;

### Feat

- Implement structure response and alert responses Fixes #9

## v1.1.2 (2024-11-13)

## v1.1.1 (2024-11-10)

## v1.1.0 (2024-10-03)

## v1.0.3 (2024-10-03)

## v1.0.2 (2024-10-03)

## v1.0.1 (2024-10-03)

## v1.0.0 (2024-10-03)

## v0.1.6 (2024-08-16)

## v0.1.5 (2024-08-16)

### Feat

- Refactor BaseSkill class, enhance unit tests, and implement centralized logging

## v0.1.4 (2024-08-04)

## v0.1.3 (2024-07-16)

## v0.1.2 (2024-07-14)

## v0.1.0 (2024-04-15)
